<?php
// Obtener el token desde la sesión (o de la caché)
session_start();
$token = isset($_SESSION['access_token']) ? $_SESSION['access_token'] : '';

$casos = [];

if ($token) {
    // URL de la API
    $url = 'http://172.16.80.2/API-Sistema-Consejeria/api/v1/caso?pagina=1&por-pagina=10&cerrados=true';

    // Inicializar cURL
    $ch = curl_init($url);

    // Configurar opciones de cURL
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_HTTPHEADER, [
        'Authorization: Bearer ' . $token,
        'Accept: application/json'
    ]);

    // Ejecutar la solicitud y obtener la respuesta
    $response = curl_exec($ch);
    $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);

    // Verificar si hubo errores
    if ($httpCode == 200) {
        $data = json_decode($response, true);
        $casos = isset($data['data']) ? $data['data'] : [];
    } else {
        $casos = ['error' => 'Error al obtener los casos'];
    }

    // Cerrar la sesión cURL
    curl_close($ch);
}
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Lista de Casos</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            margin: 20px;
            padding: 0;
            background-color: #f4f4f4;
        }

        h1 {
            color: #333;
        }

        table {
            width: 100%;
            border-collapse: collapse;
            margin-top: 20px;
            background-color: #fff;
        }

        table, th, td {
            border: 1px solid black;
        }

        th, td {
            padding: 10px;
            text-align: left;
        }

        th {
            background-color: #f2f2f2;
        }

        tr:nth-child(even) {
            background-color: #f9f9f9;
        }

        .error {
            color: red;
        }
    </style>
</head>
<body>
    <h1>Lista de Casos</h1>
    <table>
        <thead>
            <tr>
                <th>ID</th>
                <th>Fecha Inicio</th>
                <th>Fecha Cierre</th>
                <th>Servicio</th>
                <th>Prioridad</th>
                <th>Estado</th>
                <th>Acciones</th>
            </tr>
        </thead>
        <tbody>
            <?php if (isset($casos['error'])): ?>
                <tr>
                    <td colspan="7" class="error"><?php echo htmlspecialchars($casos['error']); ?></td>
                </tr>
            <?php elseif (empty($casos)): ?>
                <tr>
                    <td colspan="7">No se encontraron casos.</td>
                </tr>
            <?php else: ?>
                <?php foreach ($casos as $caso): ?>
                    <tr>
                        <td><?php echo htmlspecialchars($caso['id']); ?></td>
                        <td><?php echo htmlspecialchars($caso['fecha_inicio']); ?></td>
                        <td><?php echo $caso['fecha_cierre'] ? htmlspecialchars($caso['fecha_cierre']) : 'No cerrado'; ?></td>
                        <td><?php echo htmlspecialchars($caso['servicio']); ?></td>
                        <td><?php echo htmlspecialchars($caso['prioridad']); ?></td>
                        <td><?php echo htmlspecialchars($caso['estado']); ?></td>
                        <td>
                            <a href="<?php echo htmlspecialchars($caso['_links']['self']); ?>">Ver</a> |
                            <a href="<?php echo htmlspecialchars($caso['_links']['update']); ?>">Editar</a> |
                            <a href="<?php echo htmlspecialchars($caso['_links']['cerrar']); ?>">Cerrar</a> |
                            <a href="<?php echo htmlspecialchars($caso['_links']['delete']); ?>">Eliminar</a>
                        </td>
                    </tr>
                <?php endforeach; ?>
            <?php endif; ?>
        </tbody>
    </table>
</body>
</html>
