<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Crear Usuario</title>
    <style>
        /* Incluye aquí tu CSS existente */
        body {
            font-family: Arial, sans-serif;
            margin: 0;
            padding: 0;
            background-color: white;
            color: #048792;
        }

        .container {
            display: flex;
            height: 100vh;
        }

        .sidebar {
            width: 150px;
            background-color: white;
            color: #048792;
            padding: 20px;
            box-shadow: 2px 0 5px rgba(4, 135, 146, 0.8);
            border-right: 1px solid #048792;
            display: flex;
            flex-direction: column;
            justify-content: space-between;
            z-index: 1000;
        }

        .sidebar .logo {
            text-align: center;
            margin-bottom: 20px;
        }

        .sidebar .logo img {
            max-width: 100%;
            height: auto;
        }

        .sidebar .user-info {
            margin-bottom: 30px;
        }

        .sidebar .user-info p {
            margin: 0;
            text-align: center;
            color: #048792;
        }

        .sidebar .menu ul {
            list-style-type: none;
            padding: 0;
        }

        .sidebar .menu ul li {
            margin-bottom: 15px;
        }

        .sidebar .menu ul li a {
            color: #048792;
            text-decoration: none;
            display: block;
            padding: 10px 15px;
            border-radius: 4px;
            transition: background-color 0.3s;
        }

        .sidebar .menu ul li a:hover {
            background-color: #f1f1f1;
        }

        .content {
            flex: 1;
            background-color: white;
            padding: 20px;
        }

        .content h1 {
            color: #048792;
        }

        .sidebar-footer {
            text-align: center;
            padding: 10px;
            background-color: #fff;
            color: #048792;
            flex-shrink: 0;
            margin-top: auto;
        }

        /* Estilos adicionales para el formulario */
        .form-container {
            background-color: #fff;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
            max-width: 600px;
            margin: 0 auto;
        }

        .form-container h2 {
            margin-bottom: 20px;
            color: #048792;
        }

        .form-container label {
            display: block;
            margin-bottom: 8px;
            color: #048792;
        }

        .form-container input, .form-container select {
            width: 100%;
            padding: 8px;
            margin-bottom: 12px;
            border: 1px solid #ccc;
            border-radius: 4px;
        }

        .form-container button {
            width: 100%;
            padding: 10px;
            border: none;
            background-color: #048792;
            color: #fff;
            border-radius: 4px;
            font-size: 16px;
        }

        .form-container button:hover {
            background-color: #036b6c;
        }
    </style>
</head>
<body>
    <div class="container">
        <div class="content">
            <h1>Crear Usuario</h1>
            <div class="form-container">
                <h2>Datos del Usuario</h2>
                <form id="createUserForm">
                    <label for="identificacion">Identificación:</label>
                    <input type="text" id="identificacion" name="identificacion" required>

                    <label for="nombre">Nombre:</label>
                    <input type="text" id="nombre" name="nombre" required>

                    <label for="apellido">Apellido:</label>
                    <input type="text" id="apellido" name="apellido" required>

                    <label for="genero_id">Género:</label>
                    <select id="genero_id" name="genero_id" required>
                        <option value="1">Masculino</option>
                        <option value="2">Femenino</option>
                    </select>

                    <label for="rol_id">Rol:</label>
                    <select id="rol_id" name="rol_id" required>
                        <option value="1">Usuario</option>
                        <option value="2">Admin</option>
                    </select>

                    <label for="correo">Correo:</label>
                    <input type="email" id="correo" name="correo" required>

                    <label for="contrasena">Contraseña:</label>
                    <input type="password" id="contrasena" name="contrasena" required>

                    <label for="telefono">Teléfono:</label>
                    <input type="tel" id="telefono" name="telefono" required>

                    <label for="fecha_nacimiento">Fecha de Nacimiento:</label>
                    <input type="date" id="fecha_nacimiento" name="fecha_nacimiento" required>

                    <button type="submit">Crear Usuario</button>
                </form>
            </div>
        </div>
    </div>

    <script>
        // Función para obtener el valor de una cookie por su nombre
        function getCookie(name) {
            const value = `; ${document.cookie}`;
            const parts = value.split(`; ${name}=`);
            if (parts.length === 2) return parts.pop().split(';').shift();
        }

        // Validación del token antes de cargar la página
        function checkTokenExpiry() {
            const token = getCookie('access_token');
            const expiryTime = localStorage.getItem('token_expiry');

            console.log('Token:', token);
            console.log('Hora de expiración:', expiryTime);

            //if (!token || !expiryTime || Date.now() >= parseInt(expiryTime)) {
                //window.location.href = 'login.html';
                //return false;
            }
            return token;
        }

        // Llama a la función para validar el token
        const token = checkTokenExpiry();

        // Crear Usuario
        document.getElementById('createUserForm').addEventListener('submit', async (event) => {
            event.preventDefault();

            const identificacion = document.getElementById('identificacion').value;
            const nombre = document.getElementById('nombre').value;
            const apellido = document.getElementById('apellido').value;
            const genero_id = document.getElementById('genero_id').value;
            const rol_id = document.getElementById('rol_id').value;
            const correo = document.getElementById('correo').value;
            const contrasena = document.getElementById('contrasena').value;
            const telefono = document.getElementById('telefono').value;
            const fecha_nacimiento = document.getElementById('fecha_nacimiento').value;

            try {
                if (!token) return; // Si el token es inválido, no envíes la solicitud

                const response = await fetch('/API-Sistema-Consejeria/api/v1/usuario', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json',
                        'Authorization': `Bearer ${token}`,
                        'X-CSRF-TOKEN': '' // Incluye el token CSRF si es requerido
                    },
                    body: JSON.stringify({
                        identificacion,
                        nombre,
                        apellido,
                        genero_id: parseInt(genero_id),  // Asegúrate de que los ID se envíen como números
                        rol_id: parseInt(rol_id),
                        correo,
                        contrasena,
                        telefono,
                        fecha_nacimiento
                    })
                });

                if (!response.ok) {
                    throw new Error('Error al crear el usuario');
                }

                const data = await response.json();
                console.log('Usuario creado con éxito:', data);
                alert('Usuario creado con éxito');

                // Puedes redirigir o actualizar la lista de usuarios aquí
            } catch (error) {
                console.error('Error en el servidor:', error);
                alert('Error al crear el usuario');
            }
        });
    </script>
    <script src="funciones/auth.js" defer></script> <!-- validar token --> 
</body>
</html>
